==> jc-1.4.0.tar.gz: soot/toolkits/graph/ReversePseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.ReversePseudoTopologicalOrderer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9367d2347eb17f soot_toolkits_graph_PseudoTopologicalOrderer
// @dep_class da9fdedf84b79a19 soot_toolkits_graph_ReversePseudoTopologicalOrderer

// header file dependencies
// @dep_header soot_toolkits_graph_PseudoTopologicalOrderer

#include "soot/toolkits/graph/PseudoTopologicalOrderer.h"

#ifndef _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object;

typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	soot_toolkits_graph_PseudoTopologicalOrderer;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ReversePseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/ReversePseudoTopologicalOrderer.h <==
// public class soot.toolkits.graph.ReversePseudoTopologicalOrderer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9367d2347eb17f soot_toolkits_graph_PseudoTopologicalOrderer
// @dep_class da9fdedf84b79a19 soot_toolkits_graph_ReversePseudoTopologicalOrderer

// header file dependencies
// @dep_header soot_toolkits_graph_PseudoTopologicalOrderer

#include "soot/toolkits/graph/PseudoTopologicalOrderer.h"

#ifndef _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_
#define _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object;

typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_PseudoTopologicalOrderer$vmethods	soot_toolkits_graph_PseudoTopologicalOrderer;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vmethods	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs {
    _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_refs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_PseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_PseudoTopologicalOrderer;
    _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$sub_nonrefs	soot_toolkits_graph_ReversePseudoTopologicalOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$object {
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$vtype _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ReversePseudoTopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ReversePseudoTopologicalOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_ReversePseudoTopologicalOrderer_H_ */
